==> arrayfire-3.6.1-6-x86_64.pkg.tar.xz: usr/share/ArrayFire/doc/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Overview", "index.htm", [
    [ "Tutorials", "usergroup0.htm", [
      [ "Installation", "installing.htm", null ],
      [ "Using on Linux", "using_on_linux.htm", null ],
      [ "Using on Windows", "using_on_windows.htm", null ],
      [ "Using on OSX", "using_on_osx.htm", null ],
      [ "Getting Started", "gettingstarted.htm", null ],
      [ "Introduction to Vectorization", "vectorization.htm", null ],
      [ "Array and Matrix Manipulation", "matrixmanipulation.htm", null ],
      [ "CUDA Interoperability", "interop_cuda.htm", null ],
      [ "OpenCL Interoperability", "interop_opencl.htm", null ],
      [ "Unified Backend", "unifiedbackend.htm", null ],
      [ "Forge Visualization", "forge_visualization.htm", null ],
      [ "Indexing", "indexing.htm", null ],
      [ "Timing ArrayFire", "timing.htm", null ],
      [ "Configuring ArrayFire Environment", "configuring_environment.htm", null ],
      [ "GFOR Usage", "page_gfor.htm", null ]
    ] ],
    [ "Functions", "modules.htm", "modules" ],
    [ "Release Notes", "releasenotes.htm", null ],
    [ "Examples", "examples.htm", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"benchmarks_2blas_8cpp-example.htm",
"group__arith__func__atanh.htm#ga4c23b18ca5b3f2ef99520b3fe20b31df",
"group__arith__func__div.htm",
"group__arith__func__gt.htm#ga37585e1bad0a7cd2b94936fd246e036a",
"group__arith__func__min.htm#ga2b842c2d86df978ff68699aeaafca794",
"group__arith__func__or.htm#ga67f58ee1fb1007aa8532bd6c2e5521a2",
"group__arith__func__sub.htm#ga417c2a733abd728ab1ce0eb6db5192db",
"group__array__mem__operator__plus__eq.htm#ga5d595592ac6552d51ca2f2f1c3e4c6d8",
"group__data__func__range.htm",
"group__gfx__func__window.htm#ga37fc7eb00ae11c25e1a60d341663d68d",
"group__imageio__func__save.htm#ga2d73aad096dd1e0022fe7369112168b8",
"group__method__mat.htm#ga5cc0f3c2307de6b82ede47c9b26da2d0",
"group__reduce__func__all__true.htm#gaf3f22add3a54fb729a969cf8f669fc2b",
"group__signal__func__fft__c2r.htm#gaa5efdfd84213a4a07d81a5d534cde5ac",
"group__stream__func__read.htm#gaf78aa8f367fbd6f408e90f0851e0557a"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> arrayfire-3.6.2-2-x86_64.pkg.tar.xz: usr/share/ArrayFire/doc/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "My Project", "index.htm", [
    [ "Overview", "index.htm", null ],
    [ "Tutorials", "usergroup0.htm", [
      [ "Installation", "installing.htm", null ],
      [ "Using on Linux", "using_on_linux.htm", null ],
      [ "Using on Windows", "using_on_windows.htm", null ],
      [ "Using on OSX", "using_on_osx.htm", null ],
      [ "Getting Started", "gettingstarted.htm", null ],
      [ "Introduction to Vectorization", "vectorization.htm", null ],
      [ "Array and Matrix Manipulation", "matrixmanipulation.htm", null ],
      [ "CUDA Interoperability", "interop_cuda.htm", null ],
      [ "OpenCL Interoperability", "interop_opencl.htm", null ],
      [ "Unified Backend", "unifiedbackend.htm", null ],
      [ "Forge Visualization", "forge_visualization.htm", null ],
      [ "Indexing", "indexing.htm", null ],
      [ "Timing ArrayFire", "timing.htm", null ],
      [ "Configuring ArrayFire Environment", "configuring_environment.htm", null ],
      [ "GFOR Usage", "page_gfor.htm", null ]
    ] ],
    [ "Functions", "modules.htm", "modules" ],
    [ "Release Notes", "releasenotes.htm", null ],
    [ "Examples", "examples.htm", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"benchmarks_2blas_8cpp-example.htm",
"group__arith__func__atanh.htm#ga4c23b18ca5b3f2ef99520b3fe20b31df",
"group__arith__func__div.htm",
"group__arith__func__gt.htm#ga37585e1bad0a7cd2b94936fd246e036a",
"group__arith__func__min.htm#ga2b842c2d86df978ff68699aeaafca794",
"group__arith__func__or.htm#ga67f58ee1fb1007aa8532bd6c2e5521a2",
"group__arith__func__sub.htm#ga417c2a733abd728ab1ce0eb6db5192db",
"group__array__mem__operator__plus__eq.htm#ga5d595592ac6552d51ca2f2f1c3e4c6d8",
"group__data__func__range.htm",
"group__gfx__func__window.htm#ga37fc7eb00ae11c25e1a60d341663d68d",
"group__imageio__func__save.htm#ga2d73aad096dd1e0022fe7369112168b8",
"group__method__mat.htm#ga5cc0f3c2307de6b82ede47c9b26da2d0",
"group__reduce__func__all__true.htm#gaf3f22add3a54fb729a969cf8f669fc2b",
"group__signal__func__fft__c2r.htm#gaa5efdfd84213a4a07d81a5d534cde5ac",
"group__stream__func__read.htm#gaf78aa8f367fbd6f408e90f0851e0557a"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
